pub trait CanMake<V> {
// Required method
fn make() -> V;
}Expand description
typenum doesn’t currently allow you to easily specify any numbers
(signed or unsigned) that can be converted to a given type. I’ve added
CanMake<V> as a trait to indicate which types can easily make a runtime
value of type V to use in type bounds.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".